@@ -3,9 +3,9 @@ library("cec2005benchmark")
 extdata <- system.file("extdata", package = "cec2005benchmark")
 
 fbias_data_path <- file.path(extdata, "fbias_data.txt")
-fbias <- as.vector(as.matrix(read.table(fbias_data_path)))
+fbias <- as.vector(as.matrix(read.table(fbias_data_path, colClasses = "numeric")))
 global_optima_path <- file.path(extdata, "global_optima.txt")
-O <- as.matrix(read.table(global_optima_path))
+O <- as.matrix(read.table(global_optima_path, colClasses = "numeric"))
 
 for (i in 1:25) {
     for (D in c(2, 10, 30, 50)) {
